precision mediump float;
uniform sampler2D inputImageTexture;
varying vec2 textureCoordinate;
uniform float spliceCount;
uniform float needColorMask;

const vec4  kYIQToR   = vec4 (1.0, 0.9563, 0.6210, 0.0);
const vec4  kYIQToG   = vec4 (1.0, -0.2721, -0.6474, 0.0);
const vec4  kYIQToB   = vec4 (1.0, -1.1070, 1.7046, 0.0);
const float COLOR_COUNT = 9.0;

void main()
{
	float spliceFactor = 1.0 / spliceCount;
	vec2 origPos = mod(textureCoordinate, spliceFactor) / spliceFactor;

	int xSplice = int(textureCoordinate.x / spliceFactor);
	int ySplice = int(textureCoordinate.y / spliceFactor);

	float colorMaskIndex = mod((float(ySplice) * spliceCount + float(xSplice)), COLOR_COUNT);
	// modify HSV
 	float Q = sin (colorMaskIndex);
    float I = cos (colorMaskIndex);
    vec4 yIQ   = vec4 (1.0, I, Q, 0.0);
	vec4 spliceMaskColor;
	spliceMaskColor.r = dot (yIQ, kYIQToR);
	spliceMaskColor.g = dot (yIQ, kYIQToG);
	spliceMaskColor.b = dot (yIQ, kYIQToB);
	spliceMaskColor.a = 1.0;
	gl_FragColor = texture2D(inputImageTexture, origPos) + spliceMaskColor * .15 * needColorMask;
}
